@@ -13,11 +13,11 @@ try:
     sys.path.insert(2, path_join(wml_location, 'watson_machine_learning_client', 'tools'))
 except pkg_resources.DistributionNotFound:
     pass
-from .utils import version
-from .client import WatsonMachineLearningAPIClient
+from watson_machine_learning_client.utils import version
+from watson_machine_learning_client.client import WatsonMachineLearningAPIClient
 
 from .utils import is_python_2
 if is_python_2():
-    from .log_util import get_logger
+    from watson_machine_learning_client.utils.log_util import get_logger
     logger = get_logger('wml_client_initialization')
     logger.warning("Python 2 is not officially supported.")
