@@ -238,8 +238,8 @@ def MLRepositoryArtifact(ml_artifact= None,
     # check if ml_artifact is a tar.gz of a tensorflow model
     if isinstance(ml_artifact, str):
 
-        if (MetaNames.FRAMEWORK_NAME in meta_props.get()) or (MetaNames.FRAMEWORK_VERSION in meta_props.get()):
-         if meta_props.get()[MetaNames.FRAMEWORK_NAME] == TENSORFLOW:
+        if (MetaNames.TYPE in meta_props.get()):
+         if "tensorflow" in meta_props.get()[MetaNames.TYPE]:
             if ("tar.gz" not in ml_artifact) and (".tgz" not in ml_artifact):
                 raise TypeError('The artifact specified ( {} ) is not of type "tar.gz" or "tgz". Only compressed archive of '
                              '"tar.gz" or "tgz" format is supported.'.format(ml_artifact))
@@ -247,26 +247,26 @@ def MLRepositoryArtifact(ml_artifact= None,
          if not os.path.exists(ml_artifact):
             raise IOError('The artifact specified ( {} ) does not exist.'.format(ml_artifact))
 
-         if MetaNames.FRAMEWORK_NAME not in meta_props.get():
+         if MetaNames.TYPE not in meta_props.get():
             raise MetaPropMissingError('Value specified for "meta_props" does not contain value for '
-                             '"MetaNames.FRAMEWORK_NAME"')
+                             '"MetaNames.TYPE"')
 
-         if MetaNames.FRAMEWORK_VERSION not in meta_props.get():
-            if meta_props.get()[MetaNames.FRAMEWORK_NAME] == PMML:
-                meta_props.add(MetaNames.FRAMEWORK_VERSION, "NA")
-            else:
-                raise MetaPropMissingError('Value specified for "meta_props" does not contain value for '
-                             '"MetaNames.FRAMEWORK_VERSION"')
+         # if MetaNames.FRAMEWORK_VERSION not in meta_props.get():
+         #    if meta_props.get()[MetaNames.TYPE] == PMML:
+         #        meta_props.add(MetaNames.FRAMEWORK_VERSION, "NA")
+         #    else:
+         #        raise MetaPropMissingError('Value specified for "meta_props" does not contain value for '
+         #                     '"MetaNames.FRAMEWORK_VERSION"')
 
-         if not MetaNames.is_supported_tar_framework(meta_props.get()[MetaNames.FRAMEWORK_NAME]):
-            raise ValueError('Value specified for MetaNames.FRAMEWORK_NAME ( {} ) is not '
-                             'supported.'.format(meta_props.get()[MetaNames.FRAMEWORK_NAME]))
+         if not MetaNames.is_supported_tar_framework(meta_props.get()[MetaNames.TYPE]):
+            raise ValueError('Value specified for MetaNames.TYPE ( {} ) is not '
+                             'supported.'.format(meta_props.get()[MetaNames.TYPE]))
 
-         if meta_props.get()[MetaNames.FRAMEWORK_NAME] == TENSORFLOW:
+         if "tensorflow" in meta_props.get()[MetaNames.TYPE]:
             return _get_tensorflow_model_tar(ml_artifact, name, meta_props)
 
-         if MetaNames.is_archive_framework(meta_props.get()[MetaNames.FRAMEWORK_NAME]):
-            if meta_props.get()[MetaNames.FRAMEWORK_NAME] == PMML and ".xml" not in ml_artifact:
+         if MetaNames.is_archive_framework(meta_props.get()[MetaNames.TYPE]):
+            if "pmml" in meta_props.get()[MetaNames.TYPE] and ".xml" not in ml_artifact:
                # check if the file is a xml file
                raise TypeError('The artifact specified ( {} ) is not an xml file.')
             return _get_generic_archive_model(ml_artifact, name, meta_props)
