@@ -1,5 +1,5 @@
 import unittest
-from watson_machine_learning_client.log_util import get_logger
+from watson_machine_learning_client.utils.log_util import get_logger
 from preparation_and_cleaning import *
 
 class TestWMLClientWithKeras2CoreML(unittest.TestCase):
